import advancedLinkIcon  from './components/advanced-link-icon';
import { RichTextToolbarButton  } from '@wordpress/block-editor';
import { applyFormat, toggleFormat, useAnchor } from '@wordpress/rich-text';
import { useState } from '@wordpress/element';
import { __ } from '@wordpress/i18n';
import { Popover, TextControl, Button, SelectControl, CheckboxControl } from '@wordpress/components';
import { SVG, Path } from '@wordpress/primitives';





const AdvancedLink = {
  title: 'Infobulle',
  tagName: 'a',
  className: 'custom-a',
  attributes: {
    //caption: 'data-caption',
    class: 'class',
    target: 'target',
    url: 'href',
    rel: 'rel'
  },  
  edit: Edit,
};


function InlineAdvancedLinkUI( {
	isActive,
	activeAttributes,
	value,
	onChange,
	//onFocusOutside,
	//stopAddingLink,
	contentRef,
	//focusOnMount,
} ) {

  
  const popoverAnchor = useAnchor( {
    editableContentElement: contentRef.current,
    settings: AdvancedLink
  } );

  return (
    <>
    <Popover
        anchor={ popoverAnchor }
        headerTitle="Class CSS"
       // position='bottom center'
        placement='bottom'
        offset={ 8 }
        className= "block-editor-url-popover"
        >
          <div class="block-editor-link-control">
          <TextControl
          label="Url"
          className="block-editor-link-control__field block-editor-link-control__text-content"
          value = { activeAttributes.url || '' }
          onChange={ 
            (newHref) => { 
                var newval = applyFormat(
                  value,
                  {
                    type: 'gutenberg-advanced-link/advanced-link',
                    attributes: {
                      //caption: classCss,
                      url: newHref,
                      class: activeAttributes.class || '' ,
                      target: activeAttributes.target || '' ,
                      rel: activeAttributes.rel || '' ,
                    }
                  }
                );
                onChange( newval );
              }
          }
          
          />

          <TextControl 
          label="Class"
          className="block-editor-link-control__field block-editor-link-control__text-content"
          value = { activeAttributes.class || '' }
          onChange={ 
            (newClass) => { //setClassCss(classCss) 
                var newval = applyFormat(
                  value,
                  {
                    type: 'gutenberg-advanced-link/advanced-link',
                    attributes: {
                      //caption: classCss,
                      url: activeAttributes.url || '' ,
                      class: newClass,
                      target: activeAttributes.target || '' ,
                      rel: activeAttributes.rel || '' ,
                    }
                  }
                );
                onChange( newval );
              }
          }
          
          />

        <SelectControl
          className="block-editor-link-control__field block-editor-link-control__text-content"
          label="Target"
          value = { activeAttributes.target || '' }
          options={ [
              { label: '_none', value: '' },
              { label: '_blank', value: '_blank' },
              { label: '_self', value: '_self' },
              { label: '_parent', value: '_top' },
          ] }
          onChange={ 
            (newTarget) => { //setClassCss(classCss) 
                var newval = applyFormat(
                  value,
                  {
                    type: 'gutenberg-advanced-link/advanced-link',
                    attributes: {
                      url: activeAttributes.url || '' ,
                      class: activeAttributes.class || '' ,
                      target: newTarget,
                      rel: activeAttributes.rel || '' ,
                    }
                  }
                );
                onChange( newval );
              }
          }
        />
        <TextControl 
          label="Target - framename"
          className="block-editor-link-control__field block-editor-link-control__text-content"
          value = { activeAttributes.target || '' }
          onChange={ 
            (newTarget) => { //setClassCss(classCss) 
                var newval = applyFormat(
                  value,
                  {
                    type: 'gutenberg-advanced-link/advanced-link',
                    attributes: {
                      //caption: classCss,
                      url: activeAttributes.url || '' ,
                      class: activeAttributes.class || '' ,
                      target: newTarget
                    }
                  }
                );
                onChange( newval );
              }
            }
          
          />

          <CheckboxControl
            label="nofollow"
            checked={ activeAttributes.rel == 'nofollow' ? true : false }
            className="block-editor-link-control__field "
            onChange={ 
              (newNofollow) => { //setClassCss(classCss) 
                  newNofollow = newNofollow ? 'nofollow' : ''
                  var newval = applyFormat(
                    value,
                    {
                      type: 'gutenberg-advanced-link/advanced-link',
                      attributes: {
                        //caption: classCss,
                        url: activeAttributes.url || '' ,
                        class: activeAttributes.class || '' ,
                        target: activeAttributes.target || '' ,
                        rel: newNofollow
                      }
                    }
                  );
                  onChange( newval );
                }
              }
          />              
          </div>
        </Popover>
    </>
  )

}


function Edit( props ) {
    //const anchorRef = useAnchor( { editableContentElement: contentRef.current, value } );
    var isActive = props.isActive;
    var value = props.value;
    var onChange = props.onChange;
    var attributes = props.attributes;
    var contentRef = props.contentRef;
    var focusOnMount = props.focusOnMount;
    var activeAttributes = props.activeAttributes;


    const [ isVisible, setIsVisible ] = useState( false );
    const toggleVisible = () => { 
      setIsVisible( ( state ) => ! state ); 
    };
    const highlighterIcon = advancedLinkIcon
    const submitURL = () => { 
    };
    
    return (
      <>
        <RichTextToolbarButton
            icon={ highlighterIcon }
            title={ __( 'Advanced link', 'gutenberg-advanced-link' ) }
            isActive={ isActive }
            onClick={ () => { 
              onChange(
                  toggleFormat( value, {
                      type: 'gutenberg-advanced-link/advanced-link',
                  }
                  )
                  
              ); 
            } }
        />
        { isActive &&  
        <InlineAdvancedLinkUI
					//stopAddingLink={ stopAddingLink }
					//onFocusOutside={ onFocusOutside }
					isActive={ isActive }
					activeAttributes={ activeAttributes }
					value={ value }
					onChange={ onChange }
					contentRef={ contentRef }
					//focusOnMount={ shouldAutoFocus ? 'firstElement' : false }
				/>        
        }
        
      </>
    );
};

/*
    <Button
      label={ __( 'Apply' ) }
      type="submit"
      className="block-editor-link-control__search-submit has-icon"
      onClick= { submitURL }
    >
      <SVG xmlns="http://www.w3.org/2000/svg" viewBox="-2 -2 24 24" width="24" height="24" aria-hidden="true" focusable="false">
        <Path d="M6.734 16.106l2.176-2.38-1.093-1.028-3.846 4.158 3.846 4.157 1.093-1.027-2.176-2.38h2.811c1.125 0 2.25.03 3.374 0 1.428-.001 3.362-.25 4.963-1.277 1.66-1.065 2.868-2.906 2.868-5.859 0-2.479-1.327-4.896-3.65-5.93-1.82-.813-3.044-.8-4.806-.788l-.567.002v1.5c.184 0 .368 0 .553-.002 1.82-.007 2.704-.014 4.21.657 1.854.827 2.76 2.657 2.76 4.561 0 2.472-.973 3.824-2.178 4.596-1.258.807-2.864 1.04-4.163 1.04h-.02c-1.115.03-2.229 0-3.344 0H6.734z"></Path>
      </SVG>
    </Button>
*/

export default AdvancedLink;